"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = _interopRequireDefault(require("path"));
var _fileMutex = _interopRequireDefault(require("../fileMutex"));
var _fileMutexConfig = require("../../constants/fileMutexConfig");
var _accountLogin = _interopRequireDefault(require("./accountLogin"));
var _checkAuthCookies = require("./checkAuthCookies");
var _checkAuthDirectory = require("../checkAuthDirectory");
/* eslint-disable no-console */

async function performLoginSteps({
  page,
  authFilePrefix,
  useremail,
  password
}, isLoggedIn) {
  const authFile = _path.default.resolve(_path.default.join((0, _checkAuthCookies.getAuthFileDirectory)(), `${authFilePrefix}-cookies.json`));
  const lockFileName = useremail.replace(/[@.]/g, '_');
  const fileMutex = new _fileMutex.default((0, _checkAuthDirectory.getLockDirectoryPath)(), lockFileName, _fileMutexConfig.LOGIN_MUTEX_TIMEOUT);
  try {
    await fileMutex.acquire();
    await (0, _checkAuthCookies.loadCookiesIfPresent)(page, authFile);
    await page.goto(process.env.domain);
    await Promise.race([page.waitForNavigation(), page.waitForLoadState('networkidle'), page.waitForTimeout(5000)]);
    const isAlreadyLoggedIn = await isLoggedIn(page);
    if (!isAlreadyLoggedIn) {
      await (0, _accountLogin.default)(page, useremail, password);
      await page.goto(process.env.domain);
      await isLoggedIn(page);
      await page.context().storageState({
        path: authFile
      });
    }
  } catch (error) {
    console.error(`Error during login for ${useremail}:`, error);
  } finally {
    try {
      await fileMutex.release();
    } catch (releaseError) {
      console.error(`Error releasing lock for ${useremail}:`, releaseError);
    }
  }
}
var _default = exports.default = performLoginSteps;