"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = _interopRequireDefault(require("path"));
var _properLockfile = _interopRequireDefault(require("proper-lockfile"));
var _fs = require("fs");
function _classPrivateMethodInitSpec(obj, privateSet) { _checkPrivateRedeclaration(obj, privateSet); privateSet.add(obj); }
function _checkPrivateRedeclaration(obj, privateCollection) { if (privateCollection.has(obj)) { throw new TypeError("Cannot initialize the same private elements twice on an object"); } }
function _classPrivateMethodGet(receiver, privateSet, fn) { if (!privateSet.has(receiver)) { throw new TypeError("attempted to get private field on non-instance"); } return fn; }
var _getLockFilePath = /*#__PURE__*/new WeakSet();
var _createDirectoryIfNotExist = /*#__PURE__*/new WeakSet();
class FileMutex {
  constructor(directory, lockFileName, options = {}) {
    _classPrivateMethodInitSpec(this, _createDirectoryIfNotExist);
    _classPrivateMethodInitSpec(this, _getLockFilePath);
    this.directory = directory;
    this.lockFileName = lockFileName + ".lock";
    this.options = options;
  }
  async acquire() {
    _classPrivateMethodGet(this, _createDirectoryIfNotExist, _createDirectoryIfNotExist2).call(this);
    const lockFilePath = _path.default.resolve(this.directory, this.lockFileName);
    try {
      if (!(0, _fs.existsSync)(lockFilePath)) {
        console.log(`[DEBUG] Creating missing lock file:`, this.lockFileName);
        (0, _fs.writeFileSync)(lockFilePath, 'locked');
      }
      await _properLockfile.default.lock(_classPrivateMethodGet(this, _getLockFilePath, _getLockFilePath2).call(this), this.options);
    } catch (err) {
      throw new Error(`Failed to acquire lock after ${this.options.retries.retries} attempts: ${err.message}`);
    }
  }
  async release() {
    try {
      await _properLockfile.default.unlock(_classPrivateMethodGet(this, _getLockFilePath, _getLockFilePath2).call(this));
    } catch (err) {
      throw new Error(`Failed to release lock: ${err.message}`);
    }
  }
}
function _getLockFilePath2() {
  return _path.default.resolve(_path.default.join(this.directory, this.lockFileName));
}
function _createDirectoryIfNotExist2() {
  if (!(0, _fs.existsSync)(this.directory)) {
    (0, _fs.mkdirSync)(this.directory, {
      recursive: true
    });
  }
}
var _default = exports.default = FileMutex;