"use strict";

var _logger = require("../../utils/logger");
function _classPrivateMethodInitSpec(obj, privateSet) { _checkPrivateRedeclaration(obj, privateSet); privateSet.add(obj); }
function _checkPrivateRedeclaration(obj, privateCollection) { if (privateCollection.has(obj)) { throw new TypeError("Cannot initialize the same private elements twice on an object"); } }
function _classPrivateMethodGet(receiver, privateSet, fn) { if (!privateSet.has(receiver)) { throw new TypeError("attempted to get private field on non-instance"); } return fn; }
var _buildTagsString = /*#__PURE__*/new WeakSet();
var _parseEdition = /*#__PURE__*/new WeakSet();
var _processSingleEdition = /*#__PURE__*/new WeakSet();
var _processMultipleEditions = /*#__PURE__*/new WeakSet();
var _getEditionArgs = /*#__PURE__*/new WeakSet();
var _buildEditionTags = /*#__PURE__*/new WeakSet();
class TagProcessor {
  constructor(editionOrder) {
    _classPrivateMethodInitSpec(this, _buildEditionTags);
    _classPrivateMethodInitSpec(this, _getEditionArgs);
    _classPrivateMethodInitSpec(this, _processMultipleEditions);
    _classPrivateMethodInitSpec(this, _processSingleEdition);
    _classPrivateMethodInitSpec(this, _parseEdition);
    _classPrivateMethodInitSpec(this, _buildTagsString);
    this.editionOrder = editionOrder;
  }
  processTags(userArgs) {
    const tagArgs = userArgs['tags'] || '';
    const edition = userArgs['edition'] || null;
    if (!edition) return tagArgs;
    const editionsArray = edition.split(',');
    const editionTags = editionsArray.length === 1 ? _classPrivateMethodGet(this, _processSingleEdition, _processSingleEdition2).call(this, editionsArray[0], tagArgs) : _classPrivateMethodGet(this, _processMultipleEditions, _processMultipleEditions2).call(this, editionsArray, tagArgs);
    return editionTags;
  }
}
function _buildTagsString2(tags, editionTags) {
  return tags && tags !== '' ? `${tags} and not (${editionTags})` : `not (${editionTags})`;
}
function _parseEdition2(edition) {
  if (edition.startsWith('<=')) return ['<=', edition.slice(2)];
  if (edition.startsWith('>=')) return ['>=', edition.slice(2)];
  if (edition.startsWith('<')) return ['<', edition.slice(1)];
  if (edition.startsWith('>')) return ['>', edition.slice(1)];
  return [null, edition];
}
function _processSingleEdition2(selectedEdition, tagArgs) {
  const editionArgs = _classPrivateMethodGet(this, _getEditionArgs, _getEditionArgs2).call(this, selectedEdition);
  if (editionArgs && editionArgs.length > 0) {
    const editionTags = _classPrivateMethodGet(this, _buildEditionTags, _buildEditionTags2).call(this, editionArgs, 'or');
    return _classPrivateMethodGet(this, _buildTagsString, _buildTagsString2).call(this, tagArgs, editionTags);
  }
  _logger.Logger.log(_logger.Logger.INFO_TYPE, `No matching editions for ${selectedEdition} found. Running with default edition`);
  return tagArgs;
}
function _processMultipleEditions2(editionsArray, tagArgs) {
  const filteredEditions = this.editionOrder.filter(edition => !editionsArray.includes(edition));
  const editionTags = _classPrivateMethodGet(this, _buildEditionTags, _buildEditionTags2).call(this, filteredEditions, 'or');
  return _classPrivateMethodGet(this, _buildTagsString, _buildTagsString2).call(this, tagArgs, editionTags);
}
function _getEditionArgs2(selectedEdition) {
  const [operator, editionValue] = _classPrivateMethodGet(this, _parseEdition, _parseEdition2).call(this, selectedEdition.toLowerCase());
  const index = this.editionOrder.findIndex(edition => edition.toLowerCase() === editionValue);
  if (index === -1) {
    _logger.Logger.log(_logger.Logger.INFO_TYPE, `No matching editions for ${selectedEdition} found. Running with default edition`);
    return [];
  }
  switch (operator) {
    case '<=':
      return this.editionOrder.slice(index + 1);
    case '>=':
      return this.editionOrder.slice(0, index);
    case '<':
      return this.editionOrder.slice(index);
    case '>':
      return this.editionOrder.slice(0, index + 1);
    default:
      return this.editionOrder.filter((_, i) => i !== index);
  }
}
function _buildEditionTags2(editionArgs, operator = 'or') {
  return editionArgs.map(edition => `@edition_${edition}`).join(` ${operator} `);
}
module.exports = TagProcessor;